    // Initialise fluid field pointer lists
    
    PtrList<volScalarField> TFluid(fluidRegions.size());
    PtrList<volScalarField> p_rghFluid(fluidRegions.size());
    PtrList<volVectorField> UFluid(fluidRegions.size());
    PtrList<volScalarField> kappatFluid(fluidRegions.size());
    PtrList<volScalarField> rhokFluid(fluidRegions.size());   
    PtrList<surfaceScalarField> phiFluid(fluidRegions.size());
    PtrList<uniformDimensionedVectorField> gFluid(fluidRegions.size());
    PtrList<incompressible::RASModel> turbulence(fluidRegions.size());
    PtrList<singlePhaseTransportModel> TransportModel(fluidRegions.size());
    PtrList<dimensionedScalar> beta(fluidRegions.size());
    PtrList<dimensionedScalar> TRef(fluidRegions.size());
    PtrList<dimensionedScalar> Pr(fluidRegions.size());
    PtrList<dimensionedScalar> Prt(fluidRegions.size());
    
    PtrList<volScalarField> ghFluid(fluidRegions.size());
    PtrList<surfaceScalarField> ghfFluid(fluidRegions.size());
    PtrList<radiation::radiationModel> radiation(fluidRegions.size());
    PtrList<volScalarField> pFluid(fluidRegions.size());
    
    List<label> pRefCellFluid(fluidRegions.size(),0);
    List<scalar> pRefValueFluid(fluidRegions.size(),0.0);


    // Populate fluid field pointer lists
    forAll(fluidRegions, i)
    {
        Info<< "*** Reading fluid mesh thermophysical properties for region "
            << fluidRegions[i].name() << nl << endl;


        Info<< "    Adding to TFluid\n" << endl;
        TFluid.set
        (
            i,
            new volScalarField
            (
                IOobject
                (
                    "T",
                    runTime.timeName(),
                    fluidRegions[i],
                    IOobject::MUST_READ,
                    IOobject::AUTO_WRITE
                ),
                fluidRegions[i]
            )            
       );

        Info<< "    Adding to p_rghFluid\n" << endl;
        p_rghFluid.set
        (
            i,
            new volScalarField
            (
                IOobject
                (
                    "p_rgh",
                    runTime.timeName(),
                    fluidRegions[i],
                    IOobject::MUST_READ,
                    IOobject::AUTO_WRITE
                ),
                fluidRegions[i]
            )
        );
        
     // kinematic turbulent thermal conductivity m2/s 
        Info<< "    Adding to kappatFluid\n" << endl;
        kappaFluid.set
        (
            i,
            new volScalarField
            (
                IOobject
                (
                    "kappat",
                    runTime.timeName(),
                    fluidRegions[i],
                    IOobject::MUST_READ,
                    IOobject::AUTO_WRITE
                ),
                fluidRegions[i]
            )
        );

        Info<< "    Adding to UFluid\n" << endl;
        UFluid.set
        (
            i,
            new volVectorField
            (
                IOobject
                (
                    "U",
                    runTime.timeName(),
                    fluidRegions[i],
                    IOobject::MUST_READ,
                    IOobject::AUTO_WRITE
                ),
                fluidRegions[i]
            )
        );
//Instead of createPhi.H because of pointers.
        Info<< "    Adding to phiFluid\n" << endl;
        phiFluid.set
        (
            i,
            new surfaceScalarField
            (
                IOobject
                (
                    "phi",
                    runTime.timeName(),
                    fluidRegions[i],
                    IOobject::READ_IF_PRESENT,
                    IOobject::AUTO_WRITE
                ),
                linearInterpolate(U) & mesh.Sf()

            )
        );
        
   //This is still a blur , this comes from readTransportProperties.H and is now included in the region
   //here I have no clue if this is ok for the transport.    
        Info<< " singlePhaseTransportModel\n" << endl;
        singlePhaseTransport.set
        (
            i,
            singlePhaseTransportModel laminarTransport
            (
                UFluid[i],
                phiFluid[i],
            ).ptr()
        );
//Here based on existing createFluidFields, looks ok

// Thermal expansion coefficient [1/K]
        beta.set
        (
            i,
            new dimensionedScalar
            (
                fluidRegions[i].laminarTransport.lookup
                (
                    "beta"
                )
            )
        );
// Reference temperature [K]
        TRef.set
        (
            i,
            new dimensionedScalar
            (
                fluidRegions[i].laminarTransport.lookup
                (
                    "TRef"
                )
            )
        );

    // Laminar Prandtl number
        Pr.set
        (
            i,
            new dimensionedScalar
            (
                fluidRegions[i].laminarTransport.lookup
                (
                    "Pr"
                )
            )
        );    

    // Turbulent Prandtl number
         Prt.set
        (
            i,
            new dimensionedScalar
            (
                fluidRegions[i].laminarTransport.lookup
                (
                    "Prt"
                )
            )
        );

        Info<< "    Adding to turbulence\n" << endl;
        turbulence.set
        (
            i,
            incompressible::RASModel::New
            (
                UFluid[i],
                phiFluid[i],
                laminarTransport
            ).ptr()
        );

    
//in original file, not in buoyantSimpleFoam so I left it.
        Info<< "    Adding to gFluid\n" << endl;
        gFluid.set
        (
            i,
            new uniformDimensionedVectorField
            (
                IOobject
                (
                    "g",
                    runTime.constant(),
                    fluidRegions[i],
                    IOobject::MUST_READ,
                    IOobject::NO_WRITE
                )
            )
        );

        Info<< "    Adding to ghFluid\n" << endl;
        ghFluid.set
        (
            i,
            new volScalarField("gh", gFluid[i] & fluidRegions[i].C())
        );

        Info<< "    Adding to ghfFluid\n" << endl;
        ghfFluid.set
        (
            i,
            new surfaceScalarField("ghf", gFluid[i] & fluidRegions[i].Cf())
        );

        pFluid.set
        (
            i,
            new volScalarField
            (
                IOobject
                (
                    "p",
                    runTime.timeName(),
                    fluidRegions[i],
                    IOobject::NO_READ,
                    IOobject::AUTO_WRITE
                ),
                p_rghFluid[i] + rhokFluid[i]*ghFluid[i]
            )
        );


        radiation.set
        (
            i,
            radiation::radiationModel::New(TFluid[i])
        );



        setRefCell
        (
            pFluid[i],
            p_rghFluid[i],
            fluidRegions[i].solutionDict().subDict("SIMPLE"),
            pRefCellFluid[i],
            pRefValueFluid[i]
        );

         if (p_rghFluid[i].needReference())
            {
                pFluid[i] += dimensionedScalar
                (
                    "p",
                    pFluid[i].dimensions(),
                    pRefValueFluid[i] - getRefCellValue(pFluid[i], pRefCellFluid[i])
                );
            }
                
    }


